@@ -7,6 +7,14 @@ from foqus.server_apis import shopify_training
 
 from ip2geotools.databases.noncommercial import DbIpCity
 
+if not LOCAL:
+    from keras.utils import multi_gpu_model
+
+from keras.applications.vgg16 import VGG16
+from keras import models
+from keras import layers
+from keras import optimizers
+
 from keras.preprocessing import image
 from multiprocessing.pool import ThreadPool, TimeoutError
 from os import listdir
@@ -24,6 +32,7 @@ import hashlib
 import inspect
 import imghdr
 import os
+import pandas as pd
 import requests
 import time
 import uuid
@@ -283,6 +292,12 @@ def download_or_remove(urls, each_url_product, download_operation=1, customer_na
 
             if USE_AWS:
                 upload_file_into_s3(fichier, input_s3 + fichier.split('/')[-2] + '/')
+            else:
+                if fichier.split('/')[-2] == project_name:
+                    file_azure = input_azure + fichier.split('/')[-1]
+                else:
+                    file_azure = input_azure + fichier.split('/')[-2] + '/' + fichier.split('/')[-1]
+                upload_file_into_azure(file_azure, fichier)
             retries = 0
             while get_file_hash(fichier) != hash_file and retries < MAX_DOWNLOAD_FILE_RETRIES:
                 logger.warning("File exists but hash is incorrect... Download again!")
@@ -290,6 +305,12 @@ def download_or_remove(urls, each_url_product, download_operation=1, customer_na
                 download(url, fichier)
                 if USE_AWS:
                     upload_file_into_s3(fichier, input_s3 + fichier.split('/')[-2] + '/')
+                else:
+                    if fichier.split('/')[-2] == project_name:
+                        file_azure = input_azure + fichier.split('/')[-1]
+                    else:
+                        file_azure = input_azure + fichier.split('/')[-2] + '/' + fichier.split('/')[-1]
+                    upload_file_into_azure(file_azure, fichier)
                 retries += 1
 
             if get_file_hash(fichier) != hash_file:
@@ -298,13 +319,6 @@ def download_or_remove(urls, each_url_product, download_operation=1, customer_na
                 logger.info("File was successfully downloaded (hash OK) >>> File path: " + fichier)
 
             hash_files = hash_files + filename + " "
-            if USE_AZURE:
-                if fichier.split('/')[-2] == project_name:
-                    upload_folder_into_azure(local_path=path_out, directory_path_azure=input_azure)
-
-                else:
-                    upload_folder_into_azure(local_path=path_out,
-                                             directory_path_azure=input_azure + fichier.split('/')[-2])
         else:
             if remove(db, resized_fichier) == 0 and delete_from_s3(
                                             output_3 + fichier.split('/')[-2] + '/' + filename) == 0:
@@ -314,7 +328,6 @@ def download_or_remove(urls, each_url_product, download_operation=1, customer_na
 
     data_product = db.get_product_details(replace_special_caractere(customer_name).replace(' ', '_'), each_url_product,
                                           project_name)
-
     if data_product:
         urls_base = data_product[1]
         hash_base = data_product[3]
@@ -830,6 +843,7 @@ def get_payment_details_cms_shopify(customer_name, customer_type, domain, access
         logger.error("Payment shopify error %s" % e)
         return False, get_user_apikey(customer_name)
 
+
 def count_product(token, url_shop):
     api_version = get_api_version_shopify()
     headers = {
@@ -846,3 +860,73 @@ def count_product(token, url_shop):
         return 0
 
 
+def fine_tune(IMG_HEIGHT, IMG_WIDTH, NUM_CLASSES):
+
+    vgg_conv = VGG16(weights='imagenet', include_top=False, input_shape=(IMG_HEIGHT, IMG_WIDTH, 3))
+
+    for layer in vgg_conv.layers[:-4]:
+        layer.trainable = False
+
+    # for layer in vgg_conv.layers:
+    #    print(layer, layer.trainable)
+
+    model = models.Sequential()
+
+    model.add(vgg_conv)
+    model.add(layers.Flatten())
+    model.add(layers.Dense(1024, activation='relu'))
+    model.add(layers.Dropout(0.5))
+    model.add(layers.Dense(NUM_CLASSES, activation='sigmoid'))
+
+    # model.summary()
+    if not LOCAL:
+        parallel_model = multi_gpu_model(model, gpus=2)
+    else:
+        parallel_model = model
+
+    parallel_model.compile(loss='categorical_crossentropy',
+                           optimizer=optimizers.RMSprop(lr=1e-4),
+                           metrics=['accuracy'])
+    return parallel_model, model
+
+def load_vectors_from_local(vectors, users):
+    '''
+    :param vectors: dict with vectors names and values initialised to empty dict
+    :param users: list of all users in database
+    :return: json with all vectors with values
+    '''
+    for user in users:
+        vector_path = VECTORS_PATH + str(user[8]) + '/' + str(user[1]) + '/'
+        try:
+            projects = os.listdir(vector_path)
+            for project in projects:
+                    vectors_project = os.listdir(vector_path + project)
+                    status = db.get_status_project(STATUS_PROJECT_TABLE, user[1], user[8], 'similars', project)
+                    if status and status[0] == 2:
+                        for vector in vectors_project:
+                            try:
+                                vector_name = vector.split('.parquet')[0]
+                                if vector_name not in vectors.keys():
+                                    logger.info(
+                                        'Vector to load  =====> %s' % (vector))
+                                    vector_data = pd.read_parquet(path=vector_path + project + '/' + vector,
+                                                                  engine='pyarrow')
+                                    vectors[vector_name] = vector_data
+                                    if vector_data is not None:
+                                        vectors[vector_name] = vector_data
+                                        logger.info('Vector %s  loaded successfully for client %s '
+                                                            % (vector_name, str(user[1])))
+                                    else:
+                                        logger.info(
+                                                    'Vector %s not loaded for client %s vector is None'
+                                                    % (vector_name, str(user[1])))
+                            except Exception as e:
+                                logger.warning("Vector not loaded %s error %s" %(vector, e))
+                    else:
+                        logger.info('Status Project not 2 %s %s' % (project, status))
+                        continue
+        except Exception as e:
+            logger.warning("Can't get the parquet file for client %s with domaine %s error %s"
+                           % (str(user[1]), str(user[8]), e))
+    logger.info("Vectors keys : %s" % vectors.keys())
+    return vectors
\ No newline at end of file
