@@ -1,54 +1,17 @@
-import uuid
 import datetime
+import uuid
 
 
 from foqus.aws_configuration import *
 from foqus.azure_configuration import *
-from foqus.database import *
 
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 
-import smtplib
-from math import ceil
+import calendar
 import codecs
-import logging
-import coloredlogs, calendar
-
-if USE_LOG_AZURE:
-
-    from azure_storage_logging.handlers import TableStorageHandler
-
-    # configure the handler and add it to the logger
-    logger = logging.getLogger(__name__)
-    handler = TableStorageHandler(account_name=LOG_AZURE_ACCOUNT_NAME,
-                                  account_key=LOG_AZURE_ACCOUNT_KEY,
-                                  extra_properties=('%(hostname)s',
-                                                    '%(levelname)s'))
-    logger.setLevel(logging.DEBUG)
-    logger.addHandler(handler)
-else:
-
-    logger = logging.getLogger(__name__)
-    coloredlogs.install()
-    logger.setLevel(logging.DEBUG)
-    # create file handler which logs even debug messages
-    fh = logging.FileHandler(LOG_PATH + 'trynfit_debug.log')
-    fh.setLevel(logging.DEBUG)
-    # create console handler with a higher log level
-    ch = logging.StreamHandler()
-    ch.setLevel(logging.ERROR)
-    # create formatter and add it to the handlers
-    formatter = logging.Formatter('[%(asctime)s] %(levelname)s [%(name)s:%(lineno)s] %(message)s', '%d/%b/%Y %H:%M:%S')
-    ch.setFormatter(formatter)
-    fh.setFormatter(formatter)
-    # add the handlers to logger
-    logger.addHandler(ch)
-    logger.addHandler(fh)
-
-# Starting connection
-db = PostgreSQL()
-db.create_users_management_table()
+import smtplib
+import time
 
 
 def send_email_when_training_started(customer_name, project_name, api, subject):
@@ -61,7 +24,7 @@ def send_email_when_training_started(customer_name, project_name, api, subject):
             logger.info("start sending email of starting training ...")
             server = smtplib.SMTP(SMTP_HOST, 587)
             server.login(SMTP_USERNAME, SMTP_PASSWORD)
-            fromaddr = "FOQUS <contact@foqus.com>"
+            fromaddr = "FOQUS <hello@foqus.ai>"
             toaddr = customer_email
             msg = MIMEMultipart()
             msg['From'] = fromaddr
@@ -86,7 +49,7 @@ def send_email_to_admin(subject, message):
             logger.info("start sending email ...")
             server = smtplib.SMTP(SMTP_HOST, 587)
             server.login(SMTP_USERNAME, SMTP_PASSWORD)
-            fromaddr = "FOQUS <contact@trynfit.com>"
+            fromaddr = "FOQUS <hello@foqus.ai>"
             toaddr = "dbellarej@trynfit.com"
             msg = MIMEMultipart()
             msg['From'] = fromaddr
@@ -107,19 +70,19 @@ def send_inscription_email(customer_email, full_url, password_client):
         logger.info("start sending inscription  email ...")
         server = smtplib.SMTP(SMTP_HOST, 587)
         server.login(SMTP_USERNAME, SMTP_PASSWORD)
-        fromaddr = "FOQUS <contact@trynfit.com>"
+        fromaddr = "FOQUS <hello@foqus.ai>"
         toaddr = customer_email
         msg = MIMEMultipart()
         msg['From'] = fromaddr
         msg['To'] = toaddr
-        msg['Subject'] = 'Activez votre compte FOQUS'
+        msg['Subject'] = 'Activate your account FOQUS'
         html_file = codecs.open(PATH_INSCRIPTION_EMAIL_CUSTOMER, 'r')
-        html = (str(html_file.read()).replace("#full_url", (full_url)).replace("#password", password_client))
+        html = (str(html_file.read()).replace("#full_url", full_url).replace("#password", password_client))
         part2 = MIMEText(html, 'html')
         msg.attach(part2)
         text = msg.as_string()
         server.sendmail(fromaddr, toaddr, text)
-        logger.info("End of sending inscrition email for client %s" %customer_email)
+        logger.info("End of sending inscrition email for client %s" % customer_email)
     except Exception as e:
         logger.info("exception in sending email ..." + str(e))
 
@@ -134,14 +97,15 @@ def send_email(customer_name, project_name, subject):
             logger.info("start sending email ...")
             server = smtplib.SMTP(SMTP_HOST, 587)
             server.login(SMTP_USERNAME, SMTP_PASSWORD)
-            fromaddr = "FOQUS <contact@focus.com>"
+            fromaddr = "FOQUS <hello@foqus.ai>"
             toaddr = customer_email
             msg = MIMEMultipart()
             msg['From'] = fromaddr
             msg['To'] = toaddr
             msg['Subject'] = subject
             html_file = codecs.open(PATH_EMAIL_CUSTOMER, 'r')
-            html = (str(html_file.read()).replace("#name", (customer_profile[0][9]))).replace("#project_name", project_name)
+            html = (str(html_file.read()).replace("#name", (customer_profile[0][9]))).replace("#project_name",
+                                                                                              project_name)
             part2 = MIMEText(html, 'html')
             msg.attach(part2)
             text = msg.as_string()
@@ -156,7 +120,7 @@ def send_email_training_started(email, project_name, customer_name, customer_typ
     server = smtplib.SMTP(SMTP_HOST, 587)
     server.login(SMTP_USERNAME, SMTP_PASSWORD)
     try:
-        fromaddr = "FOQUS <contact@trynfit.com>"
+        fromaddr = "FOQUS <hello@foqus.ai>"
         msg = MIMEMultipart()
         msg['From'] = fromaddr
         msg['To'] = email
@@ -172,7 +136,7 @@ def send_email_training_started(email, project_name, customer_name, customer_typ
         logger.error("exception ......" + str(e))
 
 
-def send_email_of_client_inscription(customer_name,date_inscription, subject):
+def send_email_of_client_inscription(customer_name, date_inscription, subject):
     customer_profile = db.get_customer_info_from_customer_name(customer_name=customer_name)
 
     for custmer in customer_profile:
@@ -188,7 +152,7 @@ def send_email_of_client_inscription(customer_name,date_inscription, subject):
             msg['To'] = toaddr
             msg['Subject'] = subject
             html_file = codecs.open(PATH_EMAIL_CLIENT_INSCRIPTION, 'r')
-            html = ((str(html_file.read()).replace("#email",customer_email))).replace("#date", date_inscription)
+            html = ((str(html_file.read()).replace("#email", customer_email))).replace("#date", date_inscription)
             part2 = MIMEText(html, 'html')
             msg.attach(part2)
             text = msg.as_string()
@@ -204,14 +168,16 @@ def create_or_update_user_apikey(user='anonymous', period_in_hours=72):
 
 
 def specified_project_status(customer_name, customer_type, project_name):
-    result = db.get_status_project(table_name="status_projects", customer=customer_name, customer_type=customer_type, api="similars", project=project_name)
+    result = db.get_status_project(table_name=STATUS_PROJECT_TABLE, customer=customer_name,
+                                   customer_type=customer_type, api="similars", project=project_name)
     return result
 
 
-def create_update_project(customer, customer_type, project_to_delete, api, status,name, training_details ,counter):
-    table_name = "status_projects"
+def create_update_project(customer, customer_type, project_to_delete, api, status,name, training_details, counter):
+    table_name = STATUS_PROJECT_TABLE
     db.create_status_projects_table(table_name)
-    db.insert_or_update_status_projects_table(table_name, customer, customer_type, project_to_delete, api, status,name,training_details ,counter)
+    db.insert_or_update_status_projects_table(table_name, customer, customer_type, project_to_delete, api, status,
+                                              name, training_details, counter)
 
 
 def is_apikey_valid(user_apikey):
@@ -224,18 +190,22 @@ def is_apikey_valid(user_apikey):
 
 
 def is_user_allowed(user_apikey):
+    dbase = PostgreSQL()
     try:
-        user = db.get_customer_from_apikey(apikey=user_apikey)[0]
+        user = dbase.get_customer_from_apikey(apikey=user_apikey)[0]
     except Exception as e:
         logger.error("exception ...................%s" % e)
         logger.error("APIKEY not found. Access forbidden for '" + str(user_apikey) + "'")
+        dbase.close_connection()
         return False
 
-    expiration = db.get_expiration_from_apikey(apikey=user_apikey)[0]
+    expiration = dbase.get_expiration_from_apikey(apikey=user_apikey)[0]
     if time.time() > expiration:
         logger.info("User '" + user + "' is not allowed because APIKEY has expired. Expiration date: " + time.ctime(
-            int(db.get_expiration_from_customer(user)[0])))
+            int(dbase.get_expiration_from_customer(user)[0])))
+        dbase.close_connection()
         return False
+    dbase.close_connection()
     return True
 
 
@@ -259,8 +229,8 @@ def get_user_apikey(customer):
 
     expiration = db.get_expiration_from_apikey(apikey=user_apikey)[0]
     if time.time() > expiration:
-        logger.error("User '" + customer + "' is not allowed because APIKEY has expired. Expiration date: " + time.ctime(
-            int(db.get_expiration_from_customer(customer)[0])))
+        logger.error("User '" + customer + "' is not allowed because APIKEY has expired. Expiration date: " +
+                     time.ctime(int(db.get_expiration_from_customer(customer)[0])))
         return None
     return user_apikey
 
@@ -293,7 +263,7 @@ def get_json_ad_categorie(json_input, customer_name, customer_type, index):
 def save_data_from_cms(customer_name, customer_type, project_name, cms, url_shop, access_token):
     db.create_cms_table()
     try:
-        db.add_or_update_cms_table(table_name="cms_client_table", customer_name=customer_name,
+        db.add_or_update_cms_table(table_name=CMS_TABLE, customer_name=customer_name,
                                    customer_type=customer_type, project_name=project_name, cms=cms, url_shop=url_shop,
                                    token=access_token)
     except Exception as e:
@@ -302,7 +272,7 @@ def save_data_from_cms(customer_name, customer_type, project_name, cms, url_shop
 
 
 def scores_repartition_per_users(customer, customer_type):
-    response_list = db.select_similars_classification_result("client_history_table", customer, customer_type)
+    response_list = db.select_similars_classification_result(HISTORY_SEARCH_TABLE, customer, customer_type)
     nb_person_10_30 = 0
     nb_person_30_50 = 0
     nb_person_50_75 = 0
@@ -354,7 +324,7 @@ def get_counter_of_last_four_months(customer, customer_type):
     request_number = []
 
     for month in lastfour_months_year:
-        value = db.select_utilistation_par_mois("client_history_table", customer, customer_type, month)
+        value = db.select_utilistation_par_mois(HISTORY_SEARCH_TABLE, customer, customer_type, month)
 
         if value:
             request_number.append(value)
@@ -379,9 +349,9 @@ def get_counter_of_last_four_months(customer, customer_type):
     else:
         current_day_in_the_last_month = today.replace(month=int(last_date_in_last_month.strftime("%m")))
 
-    utilisation_per_period = db.get_similars_request_period('client_history_table', customer, customer_type, str(first),
+    utilisation_per_period = db.get_similars_request_period(HISTORY_SEARCH_TABLE, customer, customer_type, str(first),
                                                             str(today))
-    utilisation_per_last_period = db.get_similars_request_period('client_history_table', customer, customer_type,
+    utilisation_per_last_period = db.get_similars_request_period(HISTORY_SEARCH_TABLE, customer, customer_type,
                                                                  str(first_day_of_last_month),
                                                                  str(current_day_in_the_last_month))
     if not utilisation_per_period:
@@ -392,9 +362,9 @@ def get_counter_of_last_four_months(customer, customer_type):
         user_progress_requests = 100
 
 
-    user_progress_requests_3_month = db.select_utilistation_par_mois("client_history_table", customer, customer_type,
+    user_progress_requests_3_month = db.select_utilistation_par_mois(HISTORY_SEARCH_TABLE, customer, customer_type,
                                                                      last_lastMonth_year)
-    user_progress_requests_4_month = db.select_utilistation_par_mois("client_history_table", customer, customer_type,
+    user_progress_requests_4_month = db.select_utilistation_par_mois(HISTORY_SEARCH_TABLE, customer, customer_type,
                                                                      fourth_month_ago_year)
 
     if not user_progress_requests_3_month:
@@ -456,7 +426,7 @@ def send_email_for_activate_account(first_name , customer_email, full_url):
         msg = MIMEMultipart()
         msg['From'] = fromaddr
         msg['To'] = toaddr
-        msg['Subject'] = 'Activez votre compte FOQUS'
+        msg['Subject'] = 'Activate your account FOQUS'
         html_file = codecs.open(PATH_EMAIL_ACTIVATE_ACCOUNT, 'r')
         html = ((str(html_file.read()).replace("#full_url", full_url)).replace("#first_name", first_name))
         part2 = MIMEText(html, 'html')
@@ -472,7 +442,7 @@ def number_request_by_week(customer, customer_type):
     today = datetime.date.today()
 
     current_year = str(today)[0:4]
-    num_post_week = db.get_date_counter("client_history_table", customer, customer_type, current_year)
+    num_post_week = db.get_date_counter(HISTORY_SEARCH_TABLE, customer, customer_type, current_year)
     week_list_and_value = {}
     keys=[]
     values=[]
