@@ -894,4 +894,86 @@ def delete_user_data_from_email(customer_email):
                            message_body="")
     value = value.decode('utf-8')
     rpc_queue.close()
-    return value
\ No newline at end of file
+    return value
+
+@timeit
+def all_user_projects(customer_name, customer_type, api):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'operation': 'all_user_projects',
+                                    'customer_name': customer_name,
+                                    'customer_type': customer_type,
+                                    'body': api},
+                           message_body='')
+
+    return value.decode("utf-8")
+
+
+@timeit
+def manage_project(customer_name, customer_type, api, project_name, project_id, operation):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    value = rpc_queue.call(headers={'operation': operation,
+                                    'customer_name': customer_name,
+                                    'customer_type': customer_type,
+                                    'project_name': project_name,
+                                    'project_id': project_id,
+                                    'body': api},
+                           message_body='')
+
+    return value.decode("utf-8")
+
+@timeit
+def payment_client(customer_name, customer_type, user_apikey, email,  plan_name, tva, methode_payment, operation, payment_id,
+                   payer_id, stripe_token):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    headers = {'operation': operation,
+               'customer_name': customer_name,
+               'customer_type': customer_type,
+               'customer_email': email,
+               'user_apikey': user_apikey,
+               'plan_name': plan_name,
+               'tva': str(tva),
+               'methode_payment': methode_payment,
+               'payment_id': payment_id,
+               'payer_id': payer_id,
+               'stripe_token': stripe_token}
+    value = rpc_queue.call(headers=headers,
+                           message_body='')
+    return value.decode("utf-8")
+
+@timeit
+def payment_shopify(customer_name, customer_type, user_apikey, email,  plan_name, url_cms, token_cms, operation):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    headers = {'operation': operation,
+               'customer_name': customer_name,
+               'customer_type': customer_type,
+               'customer_email': email,
+               'user_apikey': user_apikey,
+               'plan_name': plan_name,
+               'url_cms': url_cms,
+               'token_cms': token_cms}
+    value = rpc_queue.call(headers=headers,
+                           message_body='')
+    return value.decode("utf-8")
+
+
+@timeit
+def payment_info_client(customer_name, customer_type, user_apikey, name,  address, zipcode, country, city,
+                                 operation):
+    rpc_queue = RpcClient(mqueue_address=MESSAGE_QUEUE_ADDRESS, mqueue_port=MESSAGE_QUEUE_PORT,
+                          mqueue_user=MESSAGE_QUEUE_USER, mqueue_password=MESSAGE_QUEUE_PASSWORD)
+    headers = {'operation': operation,
+               'customer_name': customer_name,
+               'customer_type': customer_type,
+               'name': name,
+               'user_apikey': user_apikey,
+               'address': address,
+               'zipcode': zipcode,
+               'country': country,
+               'city': city}
+    value = rpc_queue.call(headers=headers,
+                           message_body='')
+    return value.decode("utf-8")
\ No newline at end of file
